@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Data::Hive;
 BEGIN {
-  $Data::Hive::VERSION = '1.001';
+  $Data::Hive::VERSION = '1.002';
 }
 # ABSTRACT: convenient access to hierarchical data
 
@@ -101,16 +101,16 @@ sub ITEM {
 }
 
 sub HIVE {
-  my ($self, $key) = @_;
+  my ($self, @keys) = @_;
 
-  if (! defined $key or ! length $key or ref $key) {
-    $key = '(undef)' unless defined $key;
-    Carp::croak "illegal hive path part: $key";
-  }
+  my @illegal = map  { $_ = '(undef)' if ! defined }
+                grep { ! defined or ! length or ref } @keys;
+
+  Carp::croak "illegal hive path parts: @illegal" if @illegal;
 
   return $self->NEW({
     %$self,
-    path => [ @{$self->{path}}, $key ],
+    path => [ @{$self->{path}}, @keys ],
   });
 }
 
@@ -176,7 +176,7 @@ Data::Hive - convenient access to hierarchical data
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -386,7 +386,9 @@ This shows the expected results:
 
 =head3 HIVE
 
-  $hive->HIVE('foo');   #  equivalent to $hive->foo
+  $hive->HIVE('foo');          #  equivalent to $hive->foo
+
+  $hive->HIVE('foo', 'bar');   #  equivalent to $hive->foo->bar
 
 This method returns a subhive of the current hive.  In most cases, it is
 simpler to use the lowercase hive access method.  This method is useful when
